@@ -25,7 +25,6 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
-#include <gnome.h>
 
 #include <panel-applet.h>
 
@@ -272,7 +271,7 @@ static void about_dialog_activate_link_cb (GtkAboutDialog *about,
         GtkWidget *dialog;
 	GError *error = NULL;
 	
-	if (!gnome_url_show (url, &error)) {
+	if (!g_app_info_launch_default_for_uri (url, NULL, &error)) {
 		dialog = gtk_message_dialog_new (GTK_WINDOW (about), GTK_DIALOG_MODAL, 
 		                                 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 		                                 _("Could not display URL: %s"),
@@ -1035,17 +1034,48 @@ seahorse_applet_factory (PanelApplet *applet, const gchar *iid, gpointer data)
 int 
 main (int argc, char *argv [])
 {
+    GOptionContext *context;
+    GError *error;
+    gint retval;
+
     bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     textdomain (GETTEXT_PACKAGE);
 
+    context = g_option_context_new ("");
+    g_option_context_add_group (context, gtk_get_option_group (TRUE));
+    g_option_context_add_group (context, bonobo_activation_get_goption_group ());
+    
+    
+
     seahorse_secure_memory_init ();
     
-    gnome_program_init ("seahorse-applet", VERSION, LIBGNOMEUI_MODULE, argc, argv,
-                        GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,
-                        GNOME_PROGRAM_STANDARD_PROPERTIES, GNOME_PARAM_NONE);
+    error = NULL; 
+ 	if (!g_option_context_parse (context, &argc, &argv, &error)) { 
+     	if (error) { 
+         	g_printerr ("Cannot parse arguments: %s.\n", 
+         	error->message); 
+         	g_error_free (error); 
+     	} else 
+         	g_printerr ("Cannot parse arguments.\n"); 
+         	
+     	g_option_context_free (context); 
+     	
+     	return 1; 
+ 	}
     
-    return panel_applet_factory_main ("OAFIID:GNOME_SeahorseApplet_Factory", 
+    gtk_init (&argc, &argv);
+    
+    if (!bonobo_init (&argc, argv)) {
+        g_printerr ("Cannot initialize bonobo.\n");
+        return 1;
+    }
+    
+    retval =  panel_applet_factory_main ("OAFIID:GNOME_SeahorseApplet_Factory", 
                                       SEAHORSE_TYPE_APPLET, seahorse_applet_factory, NULL);
+                                      
+    g_option_context_free (context);
+    
+    return retval;
 
 }
